@@ -42,6 +42,9 @@
  * 2003-11-16 Break out oem data decoder so each platform can handle the
  *	      oem data as it likes.
  *	      Keith Owens <kaos@sgi.com>
+ * 2005-12-14 Fix use after free bug in read_salinfo_decode_oem().
+ *	      Correct the printing of the severity code and validation bits.
+ *	      Keith Owens <kaos@sgi.com>
  */
 
 #include <errno.h>
@@ -252,11 +255,8 @@ read_salinfo_decode_oem(void)
 			break;
 		}
 		ret = 0;
-		if (!p1) {
-			p1 = strstr(buffer, protocol1);
-			if (p1)
-				p1 += sizeof(protocol1) - 1;
-		}
+		if ((p1 = strstr(buffer, protocol1)))
+			p1 += sizeof(protocol1) - 1;
 		if ((p3 = strstr(buffer, protocol3)))
 			break;
 		if (nbytes == alloc - size)
@@ -344,11 +344,11 @@ rec_header_print (sal_log_record_header_t *lh)
 {
 	iprintf("Err Record ID: %ld    SAL Rev: %2x.%02x\n", lh->id,
 			lh->revision.major, lh->revision.minor);
-	iprintf("Time: %02x%02x-%02x-%02x %02x:%02x:%02x    Severity %d\n",
+	iprintf("Time: %02x%02x-%02x-%02x %02x:%02x:%02x    Severity %d Validation bits 0x%02x\n",
 			lh->timestamp.slh_century, lh->timestamp.slh_year,
 			lh->timestamp.slh_month, lh->timestamp.slh_day,
 			lh->timestamp.slh_hour, lh->timestamp.slh_minute,
-			lh->timestamp.slh_second, lh->severity);
+			lh->timestamp.slh_second, lh->severity, lh->validation_bits);
 }
 
 /* Display the common fields from a mod_error_info entry */
